package com.diagbot.facade;

import com.diagbot.client.TranServiceClient;
import com.diagbot.client.bean.FeatureRate;
import com.diagbot.client.bean.ResponseData;
import com.diagbot.dto.ConceptPushDTO;
import com.diagbot.dto.PushDTO;
import com.diagbot.entity.Concept;
import com.diagbot.enums.ConceptTypeEnum;
import com.diagbot.enums.FeatureTypeEnum;
import com.diagbot.enums.LexiconTypeEnum;
import com.diagbot.util.ListUtil;
import com.diagbot.util.ParamConvertUtil;
import com.diagbot.vo.SearchVo;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2019/5/7 16:12
 */
@Component
public class PushFacade {
    @Autowired
    private ClinicalFacade clinicalFacade;
    @Autowired
    private ConceptFacade conceptFacade;
    @Autowired
    private TranServiceClient tranServiceClient;

    /**
     * 推理接口
     *
     * @param searchVo
     * @return ResponseData
     */
    public void pushInner(SearchVo searchVo) {
        PushDTO pushDTO = new PushDTO();
        ResponseData data = clinicalFacade.processClinicalData(searchVo);
        //大数据返回内容
        List<FeatureRate> dis = data.getDis();

        String featureType = searchVo.getFeatureType();
        String[] featureTypes = featureType.split(",|，");
        Set<String> featureTypeSet = new HashSet(Arrays.asList(featureTypes));

        //症状 概念列表
        if (featureTypeSet.contains(String.valueOf(FeatureTypeEnum.Feature_Type_Symptom.getKey()))) {
            List<FeatureRate> symptom = data.getSymptom();
            if (ListUtil.isNotEmpty(symptom)) {
                List<String> nameList = symptom.stream().map(featureRate -> featureRate.getFeatureName()).collect(Collectors.toList());
                List<Concept> concepts = conceptFacade.getListByNamesAndType(nameList, ParamConvertUtil.conceptConvert2Lib(ConceptTypeEnum.Symptom.getKey()));
                if (ListUtil.isNotEmpty(concepts)) {
                    pushDTO.setSymptom(getConceptDTOList(concepts, LexiconTypeEnum.SYMPTOM.getKey()));
                }
            }
        }
        //查体 概念列表
        if (featureTypeSet.contains(String.valueOf(FeatureTypeEnum.Feature_Type_Vital.getKey()))) {
            List<FeatureRate> vital = data.getVitals();
            if (ListUtil.isNotEmpty(vital)) {
                List<String> nameList = vital.stream().map(featureRate -> featureRate.getFeatureName()).collect(Collectors.toList());
                List<Concept> concepts = conceptFacade.getListByNamesAndType(nameList, ParamConvertUtil.conceptConvert2Lib(ConceptTypeEnum.Vital.getKey()));
                if (ListUtil.isNotEmpty(concepts)) {
                    pushDTO.setVital(getConceptDTOList(concepts, LexiconTypeEnum.VITAL_INDEX.getKey()));
                }
            }
        }
        //辅检 概念列表
        if (featureTypeSet.contains(String.valueOf(FeatureTypeEnum.Feature_Type_Pacs.getKey()))) {
            List<FeatureRate> pacs = data.getPacs();
            if (ListUtil.isNotEmpty(pacs)) {
                List<String> nameList = pacs.stream().map(featureRate -> featureRate.getFeatureName()).collect(Collectors.toList());
                List<Concept> concepts = conceptFacade.getListByNamesAndType(nameList, ParamConvertUtil.conceptConvert2Lib(ConceptTypeEnum.Pacs.getKey()));
                if (ListUtil.isNotEmpty(concepts)) {
                    pushDTO.setPacs(getConceptDTOList(concepts, LexiconTypeEnum.PACS_ITEMS.getKey()));
                }
            }
        }
    }

    /**
     * 概念转成返回格式
     *
     * @param concepts
     * @param libType
     * @return
     */
    public List<ConceptPushDTO> getConceptDTOList(List<Concept> concepts, Integer libType) {
        List<ConceptPushDTO> conceptDTOS = Lists.newLinkedList();
        if (ListUtil.isNotEmpty(concepts)) {
            for (Concept concept : concepts) {
                ConceptPushDTO conceptDTO = new ConceptPushDTO();
                conceptDTO.setConceptId(concept.getId());
                conceptDTO.setName(concept.getLibName());
                conceptDTO.setLibType(ParamConvertUtil.libConvert2Concept(libType));
                conceptDTOS.add(conceptDTO);
            }
        }
        return conceptDTOS;
    }
}